@@ -22,10 +22,12 @@
 #define COURSEPARSER_H
 
 #include "artikulatecore_export.h"
-#include <memory>
 #include <QVector>
+#include <memory>
 
-class ICourse;
+class IEditableCourse;
+class IEditablePhrase;
+class IUnit;
 class Unit;
 class Phrase;
 class Phoneme;
@@ -40,7 +42,6 @@ class QUrl;
 
 class ARTIKULATECORE_EXPORT CourseParser
 {
-
 public:
     /**
      * Load XSD file given by its file name (without ".xsd" suffix). The method searches exclusively
@@ -67,15 +68,15 @@ public:
      * @param skipIncomplete if set to true, empty units and phrases without native sound files are skipped
      * @return parsed unit
      */
-    static std::vector<std::unique_ptr<Unit>> parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes = QVector<std::shared_ptr<Phoneme>>(), bool skipIncomplete = false);
+    static std::vector<std::shared_ptr<Unit>> parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes = QVector<std::shared_ptr<Phoneme>>(), bool skipIncomplete = false);
 
-    static QDomDocument serializedDocument(ICourse *course, bool trainingExport);
-    static QDomElement serializedPhrase(Phrase *phrase, QDomDocument &document);
-    static bool exportCourseToGhnsPackage(ICourse *course, const QString &exportPath);
+    static QDomDocument serializedDocument(std::shared_ptr<IEditableCourse> course, bool trainingExport);
+    static QDomElement serializedPhrase(std::shared_ptr<IEditablePhrase> phrase, QDomDocument &document);
+    static bool exportCourseToGhnsPackage(std::shared_ptr<IEditableCourse> course, const QString &exportPath);
 
 private:
-    static std::unique_ptr<Unit> parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete, bool &ok);
-    static Phrase * parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool &ok);
+    static std::shared_ptr<Unit> parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete, bool &ok);
+    static std::shared_ptr<Phrase> parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool &ok);
     static QStringList parsePhonemeIds(QXmlStreamReader &xml, bool &ok);
     static QString parseElement(QXmlStreamReader &xml, bool &ok);
 };
